"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _reactNative = require("react-native");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function handleError(func, param) {
  let message;

  if (!param) {
    message = func;
  } else {
    message = "".concat(func, "() requires at least ").concat(param, " as its first parameter.");
  }

  console.warn(message);
  return Promise.reject(message);
}

class SyncStorage {
  constructor() {
    _defineProperty(this, "data", new Map());

    _defineProperty(this, "loading", true);
  }

  init() {
    return _reactNative.AsyncStorage.getAllKeys().then(keys => _reactNative.AsyncStorage.multiGet(keys).then(data => {
      data.forEach(this.saveItem.bind(this));
      return [...this.data];
    }));
  }

  getItem(key) {
    return this.data.get(key);
  }

  setItem(key, value) {
    if (!key) return handleError('set', 'a key');
    this.data.set(key, value);
    return _reactNative.AsyncStorage.setItem(key, typeof value === 'string' ? value : JSON.stringify(value));
  }

  removeItem(key) {
    if (!key) return handleError('remove', 'a key');
    this.data.delete(key);
    return _reactNative.AsyncStorage.removeItem(key);
  }

  saveItem(item) {
    let value;

    try {
      value = JSON.parse(item[1]);
    } catch (e) {
      ;
      [, value] = item;
    }

    this.data.set(item[0], value);
    this.loading = false;
  }

  getAllKeys() {
    return Array.from(this.data.keys());
  }

  key(i) {
    return this.getAllKeys()[i];
  }

  clear() {
    this.data.clear();
    return _reactNative.AsyncStorage.clear();
  }

}

const storage = new SyncStorage();
var _default = storage; // import storage from './storage'
// export const init = () =>
//   storage.init().then(() => {
//     const { getItem, setItem, removeItem, key, clear } = storage
//     // @ts-ignore
//     // window.localStorage = storage
//     window.localStorage = {
//       getItem,
//       key,
//       setItem,
//       removeItem,
//       clear,
//     }
//     // window.localStorage = {
//     //   _data: {},
//     //   getItem: async function (key: string) {
//     //     return this._data[key] ?? (await AsyncStorage.getItem(key))
//     //   },
//     //   key: function (i: number) {
//     //     return Object.keys(this._data)[i]
//     //   },
//     //   setItem: function (key: string, value: string) {
//     //     this._data[key] = value
//     //     AsyncStorage.setItem(key, value)
//     //   },
//     //   removeItem: function (key: string) {
//     //     delete this._data[key]
//     //     return AsyncStorage.removeItem(key)
//     //   },
//     //   clear: function () {
//     //     this._data = {}
//     //     return AsyncStorage.clear()
//     //   },
//     // }
//     setGlobalVars(window, { checkOrigin: false, win: SQLite })
//   })

exports.default = _default;
//# sourceMappingURL=storage.js.map